===============================
g2gtools
===============================

.. image:: https://badge.fury.io/py/g2gtools.png
    :target: http://badge.fury.io/py/g2gtools

.. image:: https://travis-ci.org/churchill-lab/g2gtools.png?branch=master
    :target: https://travis-ci.org/churchill-lab/g2gtools

.. image:: https://pypip.in/d/g2gtools/badge.png
    :target: https://pypi.python.org/pypi/g2gtools

.. image:: https://readthedocs.org/projects/g2gtools/badge/?version=latest
    :target: http://g2gtools.readthedocs.org/en/latest/?badge=latest
    :alt: Documentation Status


**g2gtools** creates custom genomes by incorporating (phased) SNPs and indels into reference genome, extracts regions of interest, e.g., exons or transcripts, from custom genomes, and converts coordinates of files (bam, gtf, bed) between two genomes.

* Free software: GNU General Public License v3 (GPLv3)
* Documentation: https://g2gtools.readthedocs.org.


Reference
~~~~~~~~~

Manuscript in preparation (expected in 2016).